@@ -28,7 +28,7 @@
 
 #include <glib.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "common/xfpm-common.h"
 #include "common/xfpm-icons.h"
