@@ -32,11 +32,11 @@
 #include <xfconf/xfconf.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
-#include "libxfpm/xfpm-common.h"
-#include "libxfpm/xfpm-string.h"
-#include "libxfpm/xfpm-icons.h"
+#include "xfpm-common.h"
+#include "xfpm-icons.h"
+#include "xfpm-debug.h"
 
 #include "interfaces/xfpm-settings_ui.h"
 
@@ -149,7 +149,10 @@ void        critical_level_value_changed_cb        (GtkSpinButton *w,
 void        lock_screen_toggled_cb                 (GtkWidget *w, 
 						    XfconfChannel *channel);
 
-void        cpu_freq_control_changed_cb            (GtkWidget *w, 
+void        on_battery_spin_changed		   (GtkWidget *w,
+						    XfconfChannel *channel);
+
+void        on_ac_spin_changed		   	   (GtkWidget *w,
 						    XfconfChannel *channel);
 
 void        _cursor_changed_cb 			   (GtkTreeView *view, 
@@ -702,23 +705,33 @@ lock_screen_toggled_cb (GtkWidget *w, XfconfChannel *channel)
     }
 }
 
-void
-cpu_freq_control_changed_cb (GtkWidget *w, XfconfChannel *channel)
+void on_battery_spin_changed (GtkWidget *w,  XfconfChannel *channel)
 {
-#ifdef SYSTEM_IS_LINUX
-    gboolean val = (gint) gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
+    gboolean val = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
     
-    if ( !xfconf_channel_set_bool (channel, PROPERTIES_PREFIX CPU_FREQ_CONTROL, val) )
+    if ( !xfconf_channel_set_bool (channel, PROPERTIES_PREFIX SPIN_DOWN_ON_BATTERY, val) )
     {
-	g_critical ("Unable to set value for property %s\n", CPU_FREQ_CONTROL);
+	g_critical ("Unable to set value for property %s", SPIN_DOWN_ON_BATTERY);
     }
-#endif
+    
 }
 
+void on_ac_spin_changed	(GtkWidget *w, XfconfChannel *channel)
+{
+    gboolean val = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
+    
+    if ( !xfconf_channel_set_bool (channel, PROPERTIES_PREFIX SPIN_DOWN_ON_AC, val) )
+    {
+	g_critical ("Unable to set value for property %s", SPIN_DOWN_ON_AC);
+    }
+}
 
 static void
-xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gboolean can_suspend, 
-			 gboolean can_hibernate, gboolean has_lcd_brightness, gboolean has_lid)
+xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_hibernate, 
+			  gboolean auth_suspend, gboolean can_shutdown, 
+			  gboolean can_suspend, gboolean can_hibernate, 
+			  gboolean has_lcd_brightness, gboolean has_lid,
+			  gboolean devkit_disk, gboolean can_spin_down)
 {
     gboolean valid;
     gint list_value;
@@ -733,6 +746,7 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
     GtkWidget *label;
     GtkWidget *brg;
     GtkWidget *frame;
+    GtkWidget *spin_down;
 #ifdef HAVE_DPMS
     GtkWidget *dpms_frame_on_battery;
 #endif
@@ -742,6 +756,11 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
     inact = GTK_WIDGET (gtk_builder_get_object (xml, "inactivity-on-battery"));
     
     if ( !can_suspend && !can_hibernate )
+    {
+	gtk_widget_set_sensitive (inact, FALSE);
+	gtk_widget_set_tooltip_text (inact, _("Hibernate and suspend operations not supported"));
+    }
+    else if ( !auth_suspend && !auth_hibernate )
     {
 	gtk_widget_set_sensitive (inact, FALSE);
 	gtk_widget_set_tooltip_text (inact, _("Hibernate and suspend operations not permitted"));
@@ -751,12 +770,6 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
     gtk_range_set_value (GTK_RANGE (inact), val);
     
     
-    if (!user_privilege )
-    {
-	gtk_widget_set_sensitive (battery_critical, FALSE);
-	gtk_widget_set_tooltip_text (battery_critical, _("Shutdown and hibernate operations not permitted"));
-    }
-    
     list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
     
     gtk_combo_box_set_model (GTK_COMBO_BOX(battery_critical), GTK_TREE_MODEL(list_store));
@@ -764,20 +777,23 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
     gtk_list_store_append(list_store, &iter);
     gtk_list_store_set (list_store, &iter, 0, _("Nothing"), 1, XFPM_DO_NOTHING, -1);
     
-    if ( can_suspend )
+    if ( can_suspend && auth_suspend )
     {
 	gtk_list_store_append(list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Suspend"), 1, XFPM_DO_SUSPEND, -1);
     }
     
-    if ( can_hibernate )
+    if ( can_hibernate && auth_hibernate )
     {
 	gtk_list_store_append(list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Hibernate"), 1, XFPM_DO_HIBERNATE, -1);
     }
 
-    gtk_list_store_append(list_store, &iter);
-    gtk_list_store_set (list_store, &iter, 0, _("Shutdown"), 1, XFPM_DO_SHUTDOWN, -1);
+    if ( can_shutdown )
+    {
+	gtk_list_store_append(list_store, &iter);
+	gtk_list_store_set (list_store, &iter, 0, _("Shutdown"), 1, XFPM_DO_SHUTDOWN, -1);
+    }
     
     gtk_list_store_append(list_store, &iter);
     gtk_list_store_set (list_store, &iter, 0, _("Ask"), 1, XFPM_ASK, -1);
@@ -822,12 +838,6 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
     lid = GTK_WIDGET (gtk_builder_get_object (xml, "on-battery-lid"));
     if ( has_lid )
     {
-	if (!user_privilege )
-	{
-	    gtk_widget_set_sensitive (lid, FALSE);
-	    gtk_widget_set_tooltip_text (lid, _("Shutdown and hibernate operations not permitted"));
-	}
-	
 	list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
 	
 	gtk_combo_box_set_model (GTK_COMBO_BOX(lid), GTK_TREE_MODEL(list_store));
@@ -835,13 +845,13 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
 	gtk_list_store_append(list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Nothing"), 1, LID_TRIGGER_NOTHING, -1);
 	
-	if ( can_suspend )
+	if ( can_suspend && auth_suspend )
 	{
 	    gtk_list_store_append(list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Suspend"), 1, LID_TRIGGER_SUSPEND, -1);
 	}
 	
-	if ( can_hibernate)
+	if ( can_hibernate && auth_hibernate)
 	{
 	    gtk_list_store_append(list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Hibernate"), 1, LID_TRIGGER_HIBERNATE, -1);
@@ -895,16 +905,31 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean user_privilege, gbool
 	gtk_notebook_remove_page (GTK_NOTEBOOK (nt), 1);
     }
 #endif
+
+    spin_down = GTK_WIDGET (gtk_builder_get_object (xml, "spin-down-on-battery"));
+    gtk_widget_set_sensitive (spin_down, can_spin_down);
+    
+    if ( !devkit_disk )
+    {
+	gtk_widget_hide (spin_down);
+    }
+    else if ( !can_spin_down )
+    {
+	gtk_widget_set_tooltip_text (spin_down, _("Spinning down hard disks permission denied"));
+    }
 }
 
 static void
-xfpm_settings_on_ac (XfconfChannel *channel, gboolean user_privilege, gboolean can_suspend, 
-		     gboolean can_hibernate, gboolean has_lcd_brightness, gboolean has_lid)
+xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend, 
+		     gboolean auth_hibernate, gboolean can_suspend, 
+		     gboolean can_hibernate, gboolean has_lcd_brightness, 
+		     gboolean has_lid, gboolean devkit_disk, gboolean can_spin_down)
 {
     GtkWidget *inact;
     GtkWidget *lid;
     GtkWidget *frame;
     GtkWidget *brg;
+    GtkWidget *spin_down;
     GtkListStore *list_store;
     GtkTreeIter iter;
     guint val;
@@ -918,6 +943,11 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean user_privilege, gboolean c
     inact = GTK_WIDGET (gtk_builder_get_object (xml, "inactivity-on-ac"));
     
     if ( !can_suspend && !can_hibernate )
+    {
+	gtk_widget_set_sensitive (inact, FALSE);
+	gtk_widget_set_tooltip_text (inact, _("Hibernate and suspend operations not supported"));
+    }
+    else  if ( !auth_suspend && !auth_hibernate )
     {
 	gtk_widget_set_sensitive (inact, FALSE);
 	gtk_widget_set_tooltip_text (inact, _("Hibernate and suspend operations not permitted"));
@@ -948,12 +978,6 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean user_privilege, gboolean c
     {
 	list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
 	
-	if ( !user_privilege )
-	{
-	    gtk_widget_set_sensitive (lid, FALSE);
-	    gtk_widget_set_tooltip_text (lid, _("Hibernate and suspend operations not permitted"));
-	    
-	}
 	gtk_combo_box_set_model (GTK_COMBO_BOX(lid), GTK_TREE_MODEL(list_store));
 	
 	gtk_list_store_append(list_store, &iter);
@@ -1019,10 +1043,24 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean user_privilege, gboolean c
 	gtk_notebook_remove_page (GTK_NOTEBOOK (GTK_WIDGET (gtk_builder_get_object (xml, "on-ac-notebook"))), 1);
     }
 #endif
+
+    spin_down = GTK_WIDGET (gtk_builder_get_object (xml, "spin-down-on-ac"));
+    gtk_widget_set_sensitive (spin_down, can_spin_down);
+    
+    if ( !devkit_disk )
+    {
+	gtk_widget_hide (spin_down);
+    }
+    else if ( !can_spin_down )
+    {
+	gtk_widget_set_tooltip_text (spin_down, _("Spinning down hard disks permission denied"));
+    }
+
 }
 
 static void
-xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
+xfpm_settings_general (XfconfChannel *channel, gboolean auth_hibernate, 
+		       gboolean auth_suspend, gboolean can_shutdown,  
 		       gboolean can_suspend, gboolean can_hibernate,
 		       gboolean has_sleep_button, gboolean has_hibernate_button,
 		       gboolean has_power_button)
@@ -1105,31 +1143,28 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
     
     if ( has_power_button )
     {
-	if (!user_privilege )
-	{
-	    gtk_widget_set_sensitive (power, FALSE);
-	    gtk_widget_set_tooltip_text (power, _("Hibernate and suspend operations not permitted"));
-	}
-	
 	gtk_combo_box_set_model (GTK_COMBO_BOX(power), GTK_TREE_MODEL(list_store));
 
 	gtk_list_store_append (list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Nothing"), 1, XFPM_DO_NOTHING, -1);
 	
-	if ( can_suspend )
+	if ( can_suspend && auth_suspend)
 	{
 	    gtk_list_store_append (list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Suspend"), 1, XFPM_DO_SUSPEND, -1);
 	}
 	
-	if ( can_hibernate )
+	if ( can_hibernate && auth_hibernate )
 	{
 	    gtk_list_store_append (list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Hibernate"), 1, XFPM_DO_HIBERNATE, -1);
 	}
 	
-	gtk_list_store_append (list_store, &iter);
-	gtk_list_store_set (list_store, &iter, 0, _("Shutdown"), 1, XFPM_DO_SHUTDOWN, -1);
+	if ( can_shutdown )
+	{
+	    gtk_list_store_append (list_store, &iter);
+	    gtk_list_store_set (list_store, &iter, 0, _("Shutdown"), 1, XFPM_DO_SHUTDOWN, -1);
+	}
 	
 	gtk_list_store_append (list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Ask"), 1, XFPM_ASK, -1);
@@ -1163,24 +1198,18 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
     
     if (has_hibernate_button )
     {
-	if (!user_privilege )
-	{
-	    gtk_widget_set_sensitive (hibernate, FALSE);
-	    gtk_widget_set_tooltip_text (hibernate, _("Hibernate and suspend operations not permitted"));
-	}
-	
 	gtk_combo_box_set_model (GTK_COMBO_BOX(hibernate), GTK_TREE_MODEL(list_store));
 
 	gtk_list_store_append (list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Nothing"), 1, XFPM_DO_NOTHING, -1);
 	
-	if ( can_suspend )
+	if ( can_suspend && auth_suspend)
 	{
 	    gtk_list_store_append (list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Suspend"), 1, XFPM_DO_SUSPEND, -1);
 	}
 	
-	if ( can_hibernate )
+	if ( can_hibernate && auth_hibernate )
 	{
 	    gtk_list_store_append (list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Hibernate"), 1, XFPM_DO_HIBERNATE, -1);
@@ -1190,6 +1219,7 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
 	gtk_list_store_set (list_store, &iter, 0, _("Ask"), 1, XFPM_ASK, -1);
 	
 	value = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX HIBERNATE_SWITCH_CFG, XFPM_DO_NOTHING);
+	
 	for ( valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store), &iter);
 	      valid;
 	      valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter) )
@@ -1218,24 +1248,18 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
     
     if ( has_sleep_button )
     {
-	if (!user_privilege )
-	{
-	    gtk_widget_set_sensitive (sleep_w, FALSE);
-	    gtk_widget_set_tooltip_text (sleep_w, _("Hibernate and suspend operations not permitted"));
-	}
-	
 	gtk_combo_box_set_model (GTK_COMBO_BOX(sleep_w), GTK_TREE_MODEL(list_store));
 
 	gtk_list_store_append (list_store, &iter);
 	gtk_list_store_set (list_store, &iter, 0, _("Nothing"), 1, XFPM_DO_NOTHING, -1);
 	
-	if ( can_suspend )
+	if ( can_suspend && auth_suspend )
 	{
 	    gtk_list_store_append (list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Suspend"), 1, XFPM_DO_SUSPEND, -1);
 	}
 	
-	if ( can_hibernate )
+	if ( can_hibernate && auth_hibernate)
 	{
 	    gtk_list_store_append (list_store, &iter);
 	    gtk_list_store_set (list_store, &iter, 0, _("Hibernate"), 1, XFPM_DO_HIBERNATE, -1);
@@ -1271,18 +1295,17 @@ xfpm_settings_general (XfconfChannel *channel, gboolean user_privilege,
     val = xfconf_channel_get_bool (channel, PROPERTIES_PREFIX GENERAL_NOTIFICATION_CFG, TRUE);
     
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(notify), val);
-    
 }
 
 static void
-xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean user_privilege,
+xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, 
+		        gboolean auth_hibernate, gboolean auth_suspend,
 			gboolean can_suspend, gboolean can_hibernate)
 {
     guint val;
     gchar *str;
     GtkWidget *critical_level;
     GtkWidget *lock;
-    GtkWidget *cpu;
     GtkWidget *label;
     GtkWidget *sleep_dpms_mode;
     GtkWidget *suspend_dpms_mode;
@@ -1291,6 +1314,11 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
     GtkWidget *inact_hibernate = GTK_WIDGET (gtk_builder_get_object (xml, "inactivity-hibernate"));
     
     if ( !can_suspend )
+    {
+	gtk_widget_set_sensitive (inact_suspend, FALSE);
+	gtk_widget_set_tooltip_text (inact_suspend, _("Suspend operation not supported"));
+    }
+    else if ( !auth_suspend )
     {
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (inact_hibernate), TRUE);
 	gtk_widget_set_sensitive (inact_suspend, FALSE);
@@ -1298,15 +1326,20 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
     }
     
     if ( !can_hibernate )
+    {
+	gtk_widget_set_sensitive (inact_hibernate, FALSE);
+	gtk_widget_set_tooltip_text (inact_hibernate, _("Hibernate operation not supported"));
+    }
+    else if ( !auth_hibernate)
     {
 	gtk_widget_set_sensitive (inact_hibernate, FALSE);
 	gtk_widget_set_tooltip_text (inact_hibernate, _("Hibernate operation not permitted"));
     }
    
     str = xfconf_channel_get_string (channel, PROPERTIES_PREFIX INACTIVITY_SLEEP_MODE, "Suspend");
-    if ( xfpm_strequal (str, "Suspend") )
+    if ( !g_strcmp0 (str, "Suspend") )
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (inact_suspend), TRUE);
-    else if ( xfpm_strequal (str, "Hibernate"))
+    else if ( !g_strcmp0 (str, "Hibernate"))
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (inact_hibernate), TRUE);
     else 
     {
@@ -1322,9 +1355,9 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
 #ifdef HAVE_DPMS
     str = xfconf_channel_get_string (channel, PROPERTIES_PREFIX DPMS_SLEEP_MODE, "standby");
     
-    if ( xfpm_strequal (str, "standby" ) )
+    if ( !g_strcmp0 (str, "standby" ) )
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (sleep_dpms_mode), TRUE);
-    else if ( xfpm_strequal (str, "suspend") )
+    else if ( !g_strcmp0 (str, "suspend") )
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (suspend_dpms_mode), TRUE);
     else 
     {
@@ -1351,7 +1384,7 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
     
 	val = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX CRITICAL_POWER_LEVEL, 10);
 
-	if ( G_UNLIKELY (val > 20) )
+	if ( val > 20 || val < 5)
 	{
 	    g_critical ("Value %d if out of range for property %s\n", val, CRITICAL_POWER_LEVEL);
 	    gtk_spin_button_set_value (GTK_SPIN_BUTTON(critical_level), 10);
@@ -1371,7 +1404,12 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
      */
     lock = GTK_WIDGET (gtk_builder_get_object (xml, "lock-screen"));
     
-    if ( !user_privilege )
+    if ( !can_suspend && !can_hibernate )
+    {
+	gtk_widget_set_sensitive (lock, FALSE);
+	gtk_widget_set_tooltip_text (lock, _("Hibernate and suspend operations not supported"));
+    }
+    else if ( !auth_hibernate && !auth_suspend)
     {
 	gtk_widget_set_sensitive (lock, FALSE);
 	gtk_widget_set_tooltip_text (lock, _("Hibernate and suspend operations not permitted"));
@@ -1379,21 +1417,6 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
     
     val = xfconf_channel_get_bool (channel, PROPERTIES_PREFIX LOCK_SCREEN_ON_SLEEP, TRUE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(lock), val);
- 
-    cpu = GTK_WIDGET (gtk_builder_get_object (xml, "cpu-freq"));
-    
-#ifdef SYSTEM_IS_LINUX
-    if ( system_laptop )
-    {
-	val = xfconf_channel_get_bool (channel, PROPERTIES_PREFIX CPU_FREQ_CONTROL, TRUE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(cpu), val);
-    }
-    else
-	gtk_widget_hide (cpu);
-#else
-    gtk_widget_hide (cpu);
-#endif
-
 }
 
 void
@@ -1454,7 +1477,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     gtk_tree_view_append_column(GTK_TREE_VIEW(view),col);
     
     /*General settings */
-    pix = xfce_themed_icon_load ("preferences-system", 48); 
+    pix = xfpm_icon_load ("preferences-system", 48); 
     
     gtk_list_store_append(list_store, &iter);
     
@@ -1470,7 +1493,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     i++;
     
     /* ON ac power */
-    pix = xfce_themed_icon_load (XFPM_AC_ADAPTER_ICON, 48); 
+    pix = xfpm_icon_load (XFPM_AC_ADAPTER_ICON, 48); 
     gtk_list_store_append(list_store, &iter);
     if ( pix )
     {
@@ -1485,7 +1508,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     
     if ( system_laptop )
     {
-	pix = xfce_themed_icon_load (XFPM_BATTERY_ICON, 48); 
+	pix = xfpm_icon_load (XFPM_BATTERY_ICON, 48); 
 	gtk_list_store_append(list_store, &iter);
 	if ( pix )
 	{
@@ -1499,7 +1522,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     }
     i++;
     
-    pix = xfce_themed_icon_load ("applications-other", 48); 
+    pix = xfpm_icon_load ("applications-other", 48); 
     gtk_list_store_append(list_store, &iter);
     if ( pix )
     {
@@ -1548,12 +1571,14 @@ delete_event_cb (GtkWidget *plug, GdkEvent *ev, XfconfChannel *channel)
     settings_quit (plug, channel);
 }
 
-void
+GtkWidget *
 xfpm_settings_dialog_new (XfconfChannel *channel, gboolean system_laptop, 
-			  gboolean user_privilege, gboolean can_suspend, 
+			  gboolean auth_hibernate, gboolean auth_suspend, 
+			  gboolean can_shutdown, gboolean can_suspend, 
 			  gboolean can_hibernate, gboolean has_lcd_brightness, 
 			  gboolean has_lid, gboolean has_sleep_button, 
 			  gboolean has_hibernate_button, gboolean has_power_button,
+			  gboolean devkit_disk, gboolean can_spin_down, 
 			  GdkNativeWindow id)
 {
     GtkWidget *plug;
@@ -1561,19 +1586,20 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean system_laptop,
     GtkWidget *allbox;
     GError *error = NULL;
 
-    TRACE("system_laptop=%s user_privilege=%s can_suspend=%s can_hibernate=%s has_lcd_brightness=%s has_lid=%s "\
-          "has_sleep_button=%s has_hibernate_button=%s has_power_button=%s",
-	  xfpm_bool_to_string (system_laptop), xfpm_bool_to_string (user_privilege),
+    XFPM_DEBUG ("system_laptop=%s auth_hibernate=%s  auth_suspend=%s can_shutdown=%s can_suspend=%s can_hibernate=%s has_lcd_brightness=%s has_lid=%s "\
+           "has_sleep_button=%s has_hibernate_button=%s has_power_button=%s can_spin_down=%s",
+	  xfpm_bool_to_string (system_laptop), xfpm_bool_to_string (auth_hibernate), 
+	  xfpm_bool_to_string (can_shutdown), xfpm_bool_to_string (auth_suspend),
 	  xfpm_bool_to_string (can_suspend), xfpm_bool_to_string (can_hibernate),
 	  xfpm_bool_to_string (has_lcd_brightness), xfpm_bool_to_string (has_lid),
 	  xfpm_bool_to_string (has_sleep_button), xfpm_bool_to_string (has_hibernate_button),
-	  xfpm_bool_to_string (has_power_button) );
+	  xfpm_bool_to_string (has_power_button), xfpm_bool_to_string (can_spin_down) );
 
     xml = xfpm_builder_new_from_string (xfpm_settings_ui, &error);
     
     if ( G_UNLIKELY (error) )
     {
-	xfce_err ("%s : %s", error->message, _("Check your power manager installation"));
+	xfce_dialog_show_error (NULL, error, "%s", _("Check your power manager installation"));
 	g_error ("%s", error->message);
     }
     
@@ -1589,17 +1615,34 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean system_laptop,
     dialog = GTK_WIDGET (gtk_builder_get_object (xml, "xfpm-settings-dialog"));
     nt = GTK_WIDGET (gtk_builder_get_object (xml, "main-notebook"));
     
-    xfpm_settings_on_ac (channel, user_privilege, can_suspend, can_hibernate, has_lcd_brightness, has_lid );
+    xfpm_settings_on_ac (channel, 
+			 auth_hibernate, 
+			 auth_suspend, 
+			 can_suspend, 
+			 can_hibernate, 
+			 has_lcd_brightness, 
+			 has_lid,
+			 devkit_disk,
+			 can_spin_down);
     
     if ( system_laptop )
-	xfpm_settings_on_battery (channel, user_privilege, can_suspend, can_hibernate, has_lcd_brightness, has_lid);
+	xfpm_settings_on_battery (channel, 
+				  auth_hibernate, 
+				  auth_suspend, 
+				  can_shutdown, 
+				  can_suspend, 
+				  can_hibernate, 
+				  has_lcd_brightness, 
+				  has_lid,
+				  devkit_disk,
+				  can_spin_down);
 	
     xfpm_settings_tree_view (channel, system_laptop);
     
-    xfpm_settings_general   (channel, user_privilege, can_suspend, can_hibernate,
+    xfpm_settings_general   (channel, auth_hibernate, auth_suspend, can_shutdown, can_suspend, can_hibernate,
 			     has_sleep_button, has_hibernate_button, has_power_button );
 			     
-    xfpm_settings_advanced  (channel, system_laptop, user_privilege, can_suspend, can_hibernate);
+    xfpm_settings_advanced  (channel, system_laptop, auth_hibernate, auth_suspend, can_suspend, can_hibernate);
     
     if ( id != 0 )
     {
@@ -1618,4 +1661,6 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean system_laptop,
     }
     
     gtk_builder_connect_signals (xml, channel);
+    
+    return dialog;
 }
