@@ -27,6 +27,44 @@
 
 G_BEGIN_DECLS
 
+typedef enum
+{
+    XFPM_DEVICE_TYPE_UNKNOWN,
+    XFPM_DEVICE_TYPE_LINE_POWER,
+    XFPM_DEVICE_TYPE_BATTERY,
+    XFPM_DEVICE_TYPE_UPS,
+    XFPM_DEVICE_TYPE_MONITOR,
+    XFPM_DEVICE_TYPE_MOUSE,
+    XFPM_DEVICE_TYPE_KBD,
+    XFPM_DEVICE_TYPE_PDA,
+    XFPM_DEVICE_TYPE_PHONE
+    
+} XfpmDeviceType;
+  
+typedef enum
+{
+    XFPM_DEVICE_STATE_UNKNOWN,
+    XFPM_DEVICE_STATE_CHARGING,
+    XFPM_DEVICE_STATE_DISCHARGING,
+    XFPM_DEVICE_STATE_EMPTY,
+    XFPM_DEVICE_STATE_FULLY_CHARGED,
+    XFPM_DEVICE_STATE_PENDING_CHARGING,
+    XFPM_DEVICE_STATE_PENDING_DISCHARGING
+    
+} XfpmDeviceState;
+
+/*
+ * Order matters
+ */
+typedef enum
+{
+    XFPM_BATTERY_CHARGE_UNKNOWN,
+    XFPM_BATTERY_CHARGE_CRITICAL,
+    XFPM_BATTERY_CHARGE_LOW,
+    XFPM_BATTERY_CHARGE_OK
+    
+} XfpmBatteryCharge;
+
 typedef enum
 {
     XFPM_DO_NOTHING,
@@ -46,19 +84,6 @@ typedef enum
     
 } XfpmLidTriggerAction;
 
-typedef enum
-{
-    BATTERY_FULLY_CHARGED,
-    BATTERY_NOT_FULLY_CHARGED,
-    BATTERY_IS_CHARGING,
-    BATTERY_IS_DISCHARGING,
-    BATTERY_CHARGE_LOW,
-    BATTERY_CHARGE_CRITICAL,
-    BATTERY_NOT_PRESENT,
-    BATTERY_STATE_UNKNOWN
-    
-} XfpmBatteryState;
-
 typedef enum
 {
     BUTTON_UNKNOWN = 0,
@@ -81,7 +106,6 @@ typedef enum
     
 } XfpmShowIcon;
 
-
 G_END_DECLS
 
 #endif /* __XFPM_ENUM_GLIB_H */
