@@ -7,6 +7,62 @@
 
 /* enumerations from "./xfpm-enum-glib.h" */
 GType
+xfpm_device_type_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ XFPM_DEVICE_TYPE_UNKNOWN, "XFPM_DEVICE_TYPE_UNKNOWN", "unknown" },
+	{ XFPM_DEVICE_TYPE_LINE_POWER, "XFPM_DEVICE_TYPE_LINE_POWER", "line-power" },
+	{ XFPM_DEVICE_TYPE_BATTERY, "XFPM_DEVICE_TYPE_BATTERY", "battery" },
+	{ XFPM_DEVICE_TYPE_UPS, "XFPM_DEVICE_TYPE_UPS", "ups" },
+	{ XFPM_DEVICE_TYPE_MONITOR, "XFPM_DEVICE_TYPE_MONITOR", "monitor" },
+	{ XFPM_DEVICE_TYPE_MOUSE, "XFPM_DEVICE_TYPE_MOUSE", "mouse" },
+	{ XFPM_DEVICE_TYPE_KBD, "XFPM_DEVICE_TYPE_KBD", "kbd" },
+	{ XFPM_DEVICE_TYPE_PDA, "XFPM_DEVICE_TYPE_PDA", "pda" },
+	{ XFPM_DEVICE_TYPE_PHONE, "XFPM_DEVICE_TYPE_PHONE", "phone" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfpmDeviceType", values);
+  }
+	return type;
+}
+GType
+xfpm_device_state_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ XFPM_DEVICE_STATE_UNKNOWN, "XFPM_DEVICE_STATE_UNKNOWN", "unknown" },
+	{ XFPM_DEVICE_STATE_CHARGING, "XFPM_DEVICE_STATE_CHARGING", "charging" },
+	{ XFPM_DEVICE_STATE_DISCHARGING, "XFPM_DEVICE_STATE_DISCHARGING", "discharging" },
+	{ XFPM_DEVICE_STATE_EMPTY, "XFPM_DEVICE_STATE_EMPTY", "empty" },
+	{ XFPM_DEVICE_STATE_FULLY_CHARGED, "XFPM_DEVICE_STATE_FULLY_CHARGED", "fully-charged" },
+	{ XFPM_DEVICE_STATE_PENDING_CHARGING, "XFPM_DEVICE_STATE_PENDING_CHARGING", "pending-charging" },
+	{ XFPM_DEVICE_STATE_PENDING_DISCHARGING, "XFPM_DEVICE_STATE_PENDING_DISCHARGING", "pending-discharging" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfpmDeviceState", values);
+  }
+	return type;
+}
+GType
+xfpm_battery_charge_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ XFPM_BATTERY_CHARGE_UNKNOWN, "XFPM_BATTERY_CHARGE_UNKNOWN", "unknown" },
+	{ XFPM_BATTERY_CHARGE_CRITICAL, "XFPM_BATTERY_CHARGE_CRITICAL", "critical" },
+	{ XFPM_BATTERY_CHARGE_LOW, "XFPM_BATTERY_CHARGE_LOW", "low" },
+	{ XFPM_BATTERY_CHARGE_OK, "XFPM_BATTERY_CHARGE_OK", "ok" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfpmBatteryCharge", values);
+  }
+	return type;
+}
+GType
 xfpm_shutdown_request_get_type (void)
 {
 	static GType type = 0;
@@ -40,37 +96,19 @@ xfpm_lid_trigger_action_get_type (void)
 	return type;
 }
 GType
-xfpm_battery_state_get_type (void)
-{
-	static GType type = 0;
-	if (type == 0) {
-	static const GEnumValue values[] = {
-	{ BATTERY_FULLY_CHARGED, "BATTERY_FULLY_CHARGED", "fully-charged" },
-	{ BATTERY_NOT_FULLY_CHARGED, "BATTERY_NOT_FULLY_CHARGED", "not-fully-charged" },
-	{ BATTERY_IS_CHARGING, "BATTERY_IS_CHARGING", "is-charging" },
-	{ BATTERY_IS_DISCHARGING, "BATTERY_IS_DISCHARGING", "is-discharging" },
-	{ BATTERY_CHARGE_LOW, "BATTERY_CHARGE_LOW", "charge-low" },
-	{ BATTERY_CHARGE_CRITICAL, "BATTERY_CHARGE_CRITICAL", "charge-critical" },
-	{ BATTERY_NOT_PRESENT, "BATTERY_NOT_PRESENT", "not-present" },
-	{ BATTERY_STATE_UNKNOWN, "BATTERY_STATE_UNKNOWN", "state-unknown" },
-	{ 0, NULL, NULL }
-	};
-	type = g_enum_register_static ("XfpmBatteryState", values);
-  }
-	return type;
-}
-GType
 xfpm_button_key_get_type (void)
 {
 	static GType type = 0;
 	if (type == 0) {
 	static const GEnumValue values[] = {
-	{ BUTTON_POWER_OFF, "BUTTON_POWER_OFF", "power-off" },
-	{ BUTTON_HIBERNATE, "BUTTON_HIBERNATE", "hibernate" },
-	{ BUTTON_SLEEP, "BUTTON_SLEEP", "sleep" },
-	{ BUTTON_MON_BRIGHTNESS_UP, "BUTTON_MON_BRIGHTNESS_UP", "mon-brightness-up" },
-	{ BUTTON_MON_BRIGHTNESS_DOWN, "BUTTON_MON_BRIGHTNESS_DOWN", "mon-brightness-down" },
-	{ BUTTON_LID_CLOSED, "BUTTON_LID_CLOSED", "lid-closed" },
+	{ BUTTON_UNKNOWN, "BUTTON_UNKNOWN", "button-unknown" },
+	{ BUTTON_POWER_OFF, "BUTTON_POWER_OFF", "button-power-off" },
+	{ BUTTON_HIBERNATE, "BUTTON_HIBERNATE", "button-hibernate" },
+	{ BUTTON_SLEEP, "BUTTON_SLEEP", "button-sleep" },
+	{ BUTTON_MON_BRIGHTNESS_UP, "BUTTON_MON_BRIGHTNESS_UP", "button-mon-brightness-up" },
+	{ BUTTON_MON_BRIGHTNESS_DOWN, "BUTTON_MON_BRIGHTNESS_DOWN", "button-mon-brightness-down" },
+	{ BUTTON_LID_CLOSED, "BUTTON_LID_CLOSED", "button-lid-closed" },
+	{ NUMBER_OF_BUTTONS, "NUMBER_OF_BUTTONS", "number-of-buttons" },
 	{ 0, NULL, NULL }
 	};
 	type = g_enum_register_static ("XfpmButtonKey", values);
