@@ -46,14 +46,6 @@
 
 #include "xfpm-unique.h"
 
-static const gchar *BACKEND_NAME;
-static const gchar *BACKEND_PATH;
-static const gchar *BACKEND_IFACE;
-static const gchar *BACKEND_IFACE_DEVICE;
-static const gchar *BACKEND_PATH_DEVICE;
-static const gchar *BACKEND_IFACE_WAKEUPS;
-static const gchar *BACKEND_PATH_WAKEUPS;
-
 typedef struct 
 {
     DBusGConnection *bus;
@@ -354,7 +346,7 @@ xfpm_info_add_device_view (XfpmInfo *info, GHashTable *props, const gchar *objec
     gtk_list_store_append (list_store, &iter);
     gtk_list_store_set (list_store, &iter, 
 			XFPM_DEVICE_INFO_NAME, _("Device"), 
-			XFPM_DEVICE_INFO_VALUE, g_str_has_prefix (object_path, BACKEND_PATH_DEVICE) ? object_path + strlen (BACKEND_PATH_DEVICE) : object_path,
+			XFPM_DEVICE_INFO_VALUE, g_str_has_prefix (object_path, UPOWER_PATH_DEVICE) ? object_path + strlen (UPOWER_PATH_DEVICE) : object_path,
 			-1);
     i++;
     
@@ -521,7 +513,7 @@ xfpm_info_add_device (XfpmInfo *info, const gchar *object_path)
     GHashTable *props;
     
     proxy_prop = dbus_g_proxy_new_for_name (info->bus, 
-					    BACKEND_NAME,
+					    UPOWER_NAME,
 					    object_path,
 					    DBUS_INTERFACE_PROPERTIES);
 					    
@@ -531,7 +523,7 @@ xfpm_info_add_device (XfpmInfo *info, const gchar *object_path)
 	return;
     }
     
-    props = xfpm_power_get_interface_properties (proxy_prop, BACKEND_IFACE_DEVICE);
+    props = xfpm_power_get_interface_properties (proxy_prop, UPOWER_IFACE_DEVICE);
     
     if ( props )
     {
@@ -548,48 +540,11 @@ xfpm_info_power_devices (XfpmInfo *info)
     
     /*Check for upower/devkit power here*/
 
-    info->power_proxy = dbus_g_proxy_new_for_name_owner (info->bus,
-							 UPOWER_NAME,
-							 UPOWER_PATH,
-							 UPOWER_IFACE,
-							 NULL);
+    info->power_proxy = dbus_g_proxy_new_for_name (info->bus,
+						   UPOWER_NAME,
+						   UPOWER_PATH,
+						   UPOWER_IFACE);
     
-    if ( info->power_proxy )
-    {
-	BACKEND_NAME          =  UPOWER_NAME;
-	BACKEND_PATH          =  UPOWER_PATH;
-	BACKEND_IFACE         =  UPOWER_IFACE;
-	BACKEND_IFACE_DEVICE  =  UPOWER_IFACE_DEVICE;
-	BACKEND_PATH_DEVICE   =  UPOWER_PATH_DEVICE;
-	BACKEND_IFACE_WAKEUPS =  UPOWER_IFACE_WAKEUPS;
-	BACKEND_PATH_WAKEUPS  =  UPOWER_PATH_WAKEUPS;
-     }
-    else
-    {
-	g_message ("Unable to create proxy for UPower, trying DeviceKit Power...");
-	info->power_proxy = dbus_g_proxy_new_for_name_owner (info->bus,
-							     DKP_NAME,
-							     DKP_PATH,
-							     DKP_IFACE,
-							     NULL);
-	if ( info->power_proxy )
-	{
-	    g_message ("Devkit Power found in the system");
-	    
-	    BACKEND_NAME          =  DKP_NAME;
-	    BACKEND_PATH          =  DKP_PATH;
-	    BACKEND_IFACE         =  DKP_IFACE;
-	    BACKEND_IFACE_DEVICE  =  DKP_IFACE_DEVICE;
-	    BACKEND_PATH_DEVICE   =  DKP_PATH_DEVICE;
-	    BACKEND_IFACE_WAKEUPS =  DKP_IFACE_WAKEUPS;
-	    BACKEND_PATH_WAKEUPS  =  DKP_PATH_WAKEUPS;
-	}
-	else
-	{
-	    g_error ("UPower and DevkitPower are not found");
-	}
-    }
-
     array = xfpm_power_enumerate_devices (info->power_proxy);
     
     if ( array )
@@ -652,7 +607,7 @@ xfpm_info_update_wakeups (XfpmInfo *info)
 		       
     if ( !ret )
     {
-	g_warning ("GetData Failed on %s : %s", BACKEND_PATH_WAKEUPS, error->message);
+	g_warning ("GetData Failed on %s : %s", UPOWER_PATH_WAKEUPS, error->message);
 	g_error_free (error);
 	return;
     }
@@ -753,13 +708,13 @@ xfpm_info_cpu_wakeups (XfpmInfo *info)
     GtkCellRenderer *renderer;
     
     info->wakeups_proxy = dbus_g_proxy_new_for_name (info->bus,
-						     BACKEND_NAME,
-						     BACKEND_PATH_WAKEUPS,
-						     BACKEND_IFACE_WAKEUPS);
+						     UPOWER_NAME,
+						     UPOWER_PATH_WAKEUPS,
+						     UPOWER_IFACE_WAKEUPS);
 							  
     if ( !info->wakeups_proxy )
     {
-	g_warning ("Unable to create proxy for %s", BACKEND_PATH_WAKEUPS);
+	g_warning ("Unable to create proxy for %s", UPOWER_PATH_WAKEUPS);
 	return;
     }
     
